#
# spec file for package kernel-firmware
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define __find_supplements bash %{_sourcedir}/firmware.sh --find-supplements
%define __ksyms_supplements bash %{_sourcedir}/firmware.sh --cache %{_builddir}/%{?buildsubdir}/find_supplements.cache --find-supplements
%define __ksyms_path ^/lib/firmware
%define version_unconverted 20170530

Name:           kernel-firmware
Version:        20170530
Release:        20.1
Summary:        Linux kernel firmware files
License:        SUSE-Firmware AND GPL-2.0-only AND GPL-2.0-or-later AND MIT
Group:          System/Kernel
Url:            https://git.kernel.org/cgit/linux/kernel/git/firmware/linux-firmware.git/
# Created with umask 022; cd /_tmp
# After git clone https://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git
# cd linux-firmware
# git archive --format=tar --prefix=linux-firmware-$version/ -v master ./ | xz -9 -M 4G --check=crc32 -T 4 > /tmp/linux-firmware-$version.tar.xz
#
Source0:        kernel-firmware-%{version}.tar.xz
Source1:        firmware.sh
# ast_dp501_fw.bin generated from header file of xf86-video-ast: MIT/X11 License
Source2:        ast_dp501_fw.bin
Source8:        ql2600_fw.bin
Source9:        ql2700_fw.bin
Source10:       ql8300_fw.bin
# Upstream change bsc#1045856
Source11:       hfi1_dc8051.fw
Source99:       %{name}-rpmlintrc
# Intel WiFi firmware updates
Source100:      iwlwifi-3160-17.ucode
Source101:      iwlwifi-7260-17.ucode
Source102:      iwlwifi-7265-17.ucode
# bsc#1077355, CVE-2015-1142857
Source111:      bnx2x-e1-7.13.1.0.fw
Source112:      bnx2x-e1h-7.13.1.0.fw
Source113:      bnx2x-e2-7.13.1.0.fw
# CVE-2017-5715
Source200:      microcode_amd_fam15h.bin
Source201:      microcode_amd_fam17h.bin
# PATCH-FIX-UPSTREAM Update-Intel-OPA-hfi1-firmware.patch bsc#1045856
Patch1:         Update-Intel-OPA-hfi1-firmware.patch
Patch2:         WHNCE-iwlwifi-update.patch
BuildRequires:  fdupes
BuildRequires:  kernel-default
BuildRequires:  suse-module-tools
Requires(post): coreutils
Requires(postun): coreutils
Provides:       bcm43xx-firmware:/lib/firmware/brcm/brcmfmac43430-sdio.bin
Provides:       qlogic-firmware
Obsoletes:      qlogic-firmware
Provides:       cxgb3-firmware
Obsoletes:      cxgb3-firmware
Provides:       ralink-firmware
Obsoletes:      ralink-firmware
Provides:       iwl1000-ucode
Obsoletes:      iwl1000-ucode
Provides:       iwl3945-ucode
Obsoletes:      iwl3945-ucode
Provides:       iwl4965-ucode
Obsoletes:      iwl4965-ucode
Provides:       iwl5000-ucode
Obsoletes:      iwl5000-ucode
Provides:       iwl5150-ucode
Obsoletes:      iwl5150-ucode
Provides:       iwl100-ucode
Obsoletes:      iwl100-ucode
Provides:       iwl1000-ucode
Obsoletes:      iwl1000-ucode
Provides:       iwl6000-ucode
Obsoletes:      iwl6000-ucode
Provides:       iwl6050-ucode
Obsoletes:      iwl6050-ucode
Provides:       iwl6000g2-ucode
Obsoletes:      iwl6000g2-ucode
Provides:       ath3k-firmware
Obsoletes:      ath3k-firmware
Provides:       compat-wireless-firmware = 4.4
Obsoletes:      compat-wireless-firmware < 4.4
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
ExcludeArch:    %ix86 s390

%description
This package contains the firmware for in-kernel drivers that was
previously included in the kernel. It is shared by all kernels >=
2.6.27-rc1.

%package -n ucode-amd
Summary:        Microcode updates for AMD CPUs
Group:          System/Kernel
Requires(post): coreutils
Requires(postun): coreutils
Supplements:    modalias(x86cpu:vendor%%3A0002%%3Afamily%%3A*%%3Amodel%%3A*%%3Afeature%%3A*)

%description -n ucode-amd
This package contains the microcode files used by AMD CPUs.

%prep
%setup -q
cp %{S:2} %{S:8} %{S:9} %{S:10} .
# hfi1 revert (upstream change, bsc#1045856)
%patch1 -p1
cp %{S:11} .
rm -f WHENCE.orig
# Intel WiFi updates
cp %{S:100} .
cp %{S:101} .
cp %{S:102} .
%patch2 -p1
cp %{S:111} %{S:112} %{S:113} bnx2x/

%build
# nothing to do

%install
mkdir -p %{buildroot}/lib/firmware
cp -avf * %{buildroot}/lib/firmware
rm -f %{buildroot}/lib/firmware/WHENCE
bash %{_sourcedir}/firmware.sh --kill-duplicates %{buildroot}/lib/firmware/
# CVE-2017-5715 fix
cp %{SOURCE200} %{buildroot}/lib/firmware/amd-ucode/
cp %{SOURCE201} %{buildroot}/lib/firmware/amd-ucode/
%fdupes %{buildroot}
rm -f find_supplements.cache
# In alsa-firmware
rm -f %{buildroot}/lib/firmware/ctefx.bin
rm -f %{buildroot}/lib/firmware/ctspeq.bin
# Devel files
rm -rf %{buildroot}/lib/firmware/carl9170fw
# Devel files
rm -f %{buildroot}/lib/firmware/isci/{Makefile,README}
rm -f %{buildroot}/lib/firmware/isci/*.[ch]

%post
%{?regenerate_initrd_post}

%post -n ucode-amd
%{?regenerate_initrd_post}

%postun
%{?regenerate_initrd_post}

%postun -n ucode-amd
%{?regenerate_initrd_post}

%posttrans
%{?regenerate_initrd_posttrans}

%posttrans -n ucode-amd
%{?regenerate_initrd_posttrans}

%files
%defattr(0644,root,root,0755)
%doc WHENCE README GPL-2 GPL-3 LICEN[CS]E.*
%exclude /lib/firmware/amd-ucode
%exclude /lib/firmware/LICENSE.amd-ucode
/lib/firmware/*

%files -n ucode-amd
%defattr(0644,root,root,0755)
/lib/firmware/amd-ucode
/lib/firmware/LICENSE.amd-ucode

%changelog
* Mon Jun  4 2018 tiwai@suse.de
- Add microcode_amd_fam15h.bin;
  also update microcode_amd_fam17h.bin to the upstream version
  (CVE-2017-5715, bsc#1095735)
* Mon Feb 12 2018 tiwai@suse.de
- Add 7.13.1.0 bnx2x firmware files for ethernet flow control
  vulnerability in SRIOV devices (CVE-2015-1142857, bsc#1077355)
* Mon Dec 25 2017 meissner@suse.com
- Add microcode_amd_fam17h.bin (bsc#1068032 CVE-2017-5715)
* Wed Nov 15 2017 tiwai@suse.de
- Update Intel WiFi firmwares (CVE-2017-13080 CVE-2017-13081
  bsc#1066295):
  iwlwifi-3160-17.ucode
  iwlwifi-7260-17.ucode
  iwlwifi-7265-17.ucode
* Tue Jun 27 2017 tiwai@suse.de
- Revert Intel OPA hfi1 firmware to production signed v0.47
  (bsc#1045856):
  hfi1_dc8051.fw
  Update-Intel-OPA-hfi1-firmware.patch
* Thu Jun  1 2017 tiwai@suse.de
- Update to version 20170530 (bsc#1039310):
  * linux-firmware: add wil6210 firmware 4.1.0.55
  * cxgb4: update firmware to revision 1.16.45.0.
* Wed May 31 2017 tiwai@suse.de
- Cleanup spec file to reduce superfluous lines (bsc#1041354).
- Remove the superfluous isci/* devel sources
* Mon May 22 2017 tiwai@suse.de
- Update to version 20170522 (commit df40d15d6ad6) (bsc#1039785):
  * linux-firmware: liquidio: update firmware to v1.5.1
  * linux-firmware: update Marvell SD8887 firmware image
  * linux-firmware: update Marvell SD8897-B0 firmware image
  * rtl_bt: Update firmware for BT part of rtl8822be
  * cxgb4: update firmware to revision 1.16.43.0
  * linux-firmware: add Marvell USB8997 firmware image
  * iwlwifi: update -22 firmware for 3168
  * Update firmware for 3168
  * qed: Add firmware 8.20.0.0
  * Update Intel OPA hfi1 firmware
* Fri Apr 28 2017 trenn@suse.de
- According to <john.fleck@intel.com> who submitted the patch mainline and
  already gave it a test (fate#321476 and 321477):
  I see an extra file in the firmware package related to the hfi1 driver.
  /lib/firmware/hfi1_platform.dat
  This file needs to be removed from the SLES distro.
  The other files look correct.
* Tue Apr 11 2017 mmarek@suse.cz
- Update to version 20170404
  Firmware updates for qed (fate#321702), i195, amdgpu, radeon,
  rtlwifi, qla2xxx, cxgb4, Intel BT, ath10k, mwifiex, etc.
  Deleted qlogic-Update-to-08.04.00.patch, ql2400_fw.bin
  ql2500_fw.bin
- Add kernel-firmware-rpmlintrc as some firmware is binary
* Mon Feb  6 2017 tiwai@suse.de
- Update to version 20170113 (FATE#321353):
  including AMDGPU updates, Intel SST BYT/BSW, Intel SKL/BXT/KBL audio,
  Intel BT 7265 (C0/D0), 7265 (D1), 7260 (B3/B4/B5/B6), 8260 and 8265,
  qed FW 8.10.5.0 and 8.10.10.0, BRCM4356/4358, RTL8723BE/RTL8821AE,
  wl127x/wl128x, cxgb4 1.16.26.0, MT8173 VPU, rockchip dptx v3.1,
  radeon SMC, Marvell PCIe8997, ath10k QCA4019 hw1.0, QCA9887 hw1.0,
  QCA9888 hw2.0, QCA9984 hw1.0, QCA988X hw2.0 and QCA6174, rt2870sta
  rt3071.bin, RTL8822BE, i915 DMC 1.23 xhci-rcar R-Car H3 and M3-W,
  usbdux usbduxsigma, nvidia GP100, iwlwifi -17 and -22 firmwares,
- Add Provides for brcmfmac43430-sdio.bin formerly in bcm43xx-firmware
- Package new GPL-2 file
- Refresh qlogic-Update-to-08.04.00.patch
- Remove obsoleted files (already included in the updated tarball):
  cxgb4-update-firmware-to-revision-1.15.37.0.patch
  fw_sst_0f28.bin
  fw_sst_0f28_ssp0.bin
  fw_sst_22a8.bin
  qed-Add-FW-8.10.5.0.patch
  qed_init_values_zipped-8.10.5.0.bin
  t4fw-1.15.37.0.bin
  t5fw-1.15.37.0.bin
* Thu Dec  1 2016 tiwai@suse.de
- Update ASoC Intel SST Atom firmwares as of 20161201 (bsc#1010690)
* Fri Aug 26 2016 hare@suse.de
- Update qlogic qla2xxx firmware to 08.04.00 (bsc#993846)
* Wed Aug 17 2016 acho@suse.com
- Update qlogic  qed/qede - update FW to version 8.10.5.0 (bsc#993873).
* Thu Jun  2 2016 bpoirier@suse.com
- Update Chelsio cxgb4 firmware to version 1.15.37.0 (bsc#975328)
* Thu May 26 2016 mmarek@suse.com
- Update to version 20160516git / commit 80d463be829a (fate#320305).
  - Intel SKL audio update
  - rt2800usb / rt2800pci update
  - amdgpu update
- Obsolete the SP1 compat-wireless-firmware package (bsc#975894).
* Fri May  6 2016 mmarek@suse.cz
- Update to version 20160429git / commit 8afadbe55301 (fate#fate#320305).
  - radeon and amdgpu updates
  - Intel Bluetooth 7265 / 8265 updates
  - ath10k updates
* Tue Mar 29 2016 mmarek@suse.com
- Update to version 20160317git (commit 5f8ca0c1db61) (fate#fate#320305).
  - Intel wifi and BT updates (fate#319955)
  - rtlwifi update
  - Intel SKL audio and graphics updates
  - Atheros AR3012 firmware
  - nvidia GM200, GM204, GM206 and GM20B signed firmware
  - wl18xx update
  - AMD family 15h processor update
  - Intel OPA hfi1 (fate#319251)
* Fri Jan 15 2016 mmarek@suse.cz
- Update to version 20160112git (commit 40e9ae8) (fate#320305).
  No firmware files have been removed except for
  ti-connectivity/wl18xx-conf.bin, for which the driver has a
  fallback.
  Run git log --no-merges --oneline ce64fa89..40e9ae8 in linux-firmware.git
  to see the complete list of changes.
- Synced the spec file with openSUSE Factory.
* Mon Sep 14 2015 dchang@suse.com
- cxgb4: update firmware to revision 1.14.4.0 for T4 and T5
  (bsc#945218)
  - Replaced cxgb4-update-firmware-to-revision-1.13.32.0-for-T4-a.patch
    with cxgb4-update-firmware-to-revision-1.14.4.0.patch
  - Replaced t4fw-1.13.32.0.bin and t5fw-1.13.32.0.bin with
    t4fw-1.14.4.0.bin and t5fw-1.14.4.0.bin
* Tue Aug 11 2015 dchang@suse.com
- Update symlinks in cxgb4 subdirectory. (bsc#924378 FATE#318565)
* Wed Aug  5 2015 dchang@suse.com
- Update Chelsio cxgb4 firmware to revision 1.13.32.0 for T4 and T5
  (bsc#924378 FATE#318565)
  - Add t4fw-1.13.32.0.bin and t5fw-1.13.32.0.bin
* Fri Jun 26 2015 glin@suse.com
- Update QLogic bna firmware (bsc#922050, FATE#318601)
  + ctfw-3.2.5.1.bin, ct2fw-3.2.5.1.bin
- Exclude i586 and s390
* Mon Sep  8 2014 eich@suse.com
- Add ast_dp501_fw.bin (bnc#871134 & bnc#895608)
  file generated from an array in a header file of xf86-video-ast:
  MIT/X11 License
* Wed Sep  3 2014 tiwai@suse.de
- Update Intel BT 7265 firmware to fix HFP issue on EHCI
  (bnc#894810)
* Fri Aug  8 2014 mmarek@suse.cz
- Update to git snapshot 20140807
  * Includes previously cherry-picked QLogic firmware (bnc#879633)
  * Intel BT firmware updates
  * cxgb4 firmware update to revision 1.11.27.0
  * bnx2x firmware version 7.10.51 (bnc#887382)
  * Other firmware files not used by the SLE12 kernel
* Wed Aug  6 2014 mmarek@suse.cz
- Update QLogic firmware (bnc#879633)
* Tue Jul 29 2014 mmarek@suse.cz
- Add dvb-fe-xc5000c-4.1.30.7.fw for xc5000 (bnc#884321)
- Package also licence files spelled as LICENSE.*
* Thu Jul  3 2014 mmarek@suse.cz
- Drop firmware signatures (bnc#867199)
* Thu Jun 26 2014 mmarek@suse.cz
- Update to git snapshot 20140604
  * Includes previously cherry-picked Intel WiFi and BT firmware
  * Fixes for other Intel WiFi and BT firmware
  * Includes missing radeon firmware (bnc#884321)
  * New firmware for brcm and rtlwifi.
* Sun Apr 13 2014 mmarek@suse.cz
- Add # needssslcertforbuild to use the project's certificate when
  building in a home project.
* Fri Apr  4 2014 tiwai@suse.de
- Add Intel 7265 BT firmware (FATE#316958):
  ibt-hw-37.8.10-fw-1.10.2.27.d.bseq
  ibt-hw-37.8.bseq
* Fri Apr  4 2014 mmarek@suse.cz
- Regenerate the initrd in %%posttrans (fate#313506)
* Tue Apr  1 2014 mmarek@suse.cz
- Sign firmware files in the buildservice (bnc#867199)
* Mon Mar 24 2014 tiwai@suse.de
- Add Intel 7265 WiFi firmware (FATE#316958)
* Wed Mar 19 2014 tiwai@suse.de
- Update to git snapshot 20140319 (bnc#869180)
  * brcm: add firmware for the BCM43362 WLAN device
  * iwlwifi: update firmware for 7260 / 3160 devices
  * WHENCE: Fix oddly capitalised instances of 'File'
  * wl18xx: add version 3 of the wl18xx firmware
  * rtlwifi: Add firmware for rtl8192ee
  * myri10ge: update firmware to 1.4.57
  * bnx2x: Update to FW 7.8.19
  * Remove executable permissions from firmware files
  * rtlwifi: Add firmware for rtl8821ae
  * radeon: add ucode for HAWAII GPUs
  * rtlwifi: Add firmware for r8723au
  * iwlwifi: update firmware for 7260 / 3160 devices
  * iwlwifi: update firmware for 7260 / 3160 devices
  * linux-firmware: 3.2.3.0 Firmware for Brocade Adapters
  * cxgb4: Updated T4 firmware, add T5 firmware
  * qla2xxx: Update ql2{4,5}00_fw.bin to version 7.01.00
  * linux-firmware: Update Intel Bluetooth devices firmware patch files
  * firmware: cw1200: Add firmware for the ST-E CW1200 WLAN chipset.
  * emi62: Provide the correct bitstream
  * linux-firmware: add Marvell SD8897-B0 firmware combo image
  * linux-firmware: update Marvell PCIe/USB 8897-B0 firmware combo image
  * rtlwifi: Add new firmware files for rtl8188eu
  * rtlwifi: Add new firmware files for rtl8192cu
  * brcm: add firmware file for the BCM4335 SDIO chipset
  * brcm: add firmware for newer version of BCM43241 SDIO chipset
  * brcm: add firmware file for BCM43241 SDIO chipset
  * brcm: rename firmware names expressing host interface type
  * ti-connectivity: add wl1251 firmware and license
  * linux-firmware: Add Brocade FC/FCOE Adapter firmware files
  * radeon: add ucode for KAVERI GPUs
  * radeon: add smc ucode for BONAIRE
  * linux-firmware: Add firmware patch file for Intel Bluetooth device(3160)
  * linux-firmware: add version information for Intel Bluetooth firmware
  * cw1200: Add SDD file for the Sagrad SG901-1091/1098 WLAN modules.
  * Fix filename for Intel Bluetooth firmware
  * linux-firmware: update Intel Bluetooth firmware patch file
  * moxa: Fix firmware file names.
  * moxa: Add firmware for some of the Moxa USB-Serial hubs
  * radeon: add ucode for KABINI GPUs
  * radeon: add ucode for BONAIRE GPUs
  * radeon: add smc ucode for radeon GPUs
- Remove obsoleted iwlwifi-4965-1.ucode
- Remove the files that are already included in tarball:
  carl9170-1.fw, ct2fw-3.2.3.0.bin, ctfw-3.2.3.0.bin,
  iwlwifi-3160-8.ucode, iwlwifi-7260-8.ucode
* Tue Mar 18 2014 tiwai@suse.de
- iwlwifi: update firmware for 7260 / 3160 devices to 22.24.8.0
  New version includes a bunch of bug fixes especially in GO mode
  (FATE#316958)
* Wed Feb  5 2014 tiwai@suse.de
- Updated firmware versions for iwlwifi 3160 and 7260 (FATE#316958)
* Thu Jan 23 2014 bpoirier@suse.de
- linux-firmware: 3.2.3.0 Firmware for Brocade Adapters (bnc#855232
  FATE#315938)
  Limited to the bna firmware.
* Mon Dec  9 2013 trenn@suse.de
- Correct Supplements string so that the package gets correctly installed
  on machines with Intel CPUs
  bnc#847158
* Tue Oct 22 2013 jeffm@suse.com
- Use qlogic firmware from linux-firmware instead of the separate
  archive (bnc#846629).
* Mon Jul 29 2013 jeffm@suse.com
- Updated to git snapshot 2013/07/14
  - Radeon ucode update:
  - radeon: add ucode for KABINI GPUs
  - radeon: add ucode for BONAIRE GPUs
  - radeon: add smc ucode for radeon GPUs
* Thu Jul 25 2013 jeffm@suse.com
- Moved amd-ucode from microcode_ctl into new ucode-amd package.
* Fri Jul 19 2013 jeffm@suse.com
- Remove carl9170fw source files from package
* Mon Jul 15 2013 jeffm@suse.com
- Updated to git snapshot 2013/7/10
  - Add AMD microcode patch firmware files
  - Add Intel Bluetooth firmware patch files
  - Add firmware files for Creative CA0132 HD-audio codec
  - Add firmware files for mtk mt7630/mt7650 chipsets
  - Add firmware for mwl8k 8764 chip
  - Add go7007 firmware.
  - Add symlinks for old go7007 firmware filenames
  - Fix formatting of LICENCE.ca0132
  - Increment ap firmware API for mwl8k 8366 chip
  - Move sd8688*.bin images into mrvl/ tree
  - Revert "carl9170: Add checksum during installation, as preferred by the driver"
  - add Marvell PCIe8897-B0 WLAN firmware image
  - add Marvell SD8797-B0 firmware image
  - ar3k: add Bluetooth support for QCA98XX/QCA24XX
  - bnx2x: update fw to 7.8.17
  - cx231xx/cx23885: Remove incorrect Conexant CX23885 firmware
  - iwlwifi: add firmware for 7260 / 3160 devices
  - netxen_nic: Add FTP location of phanfw.bin in WHENCE file
  - netxen_nic: Update QLogic phanfw.bin to version 4.0.590
  - radeon: add ucode for OLAND GPUs
  - radeon: add ucode for SUN/HAINAN GPUs
  - radeon: add updated ucode for UVD
  - rp2: Initial commit of Comtrol RocketPort 2 microcode
  - rtl_nic: Add firmware rtl8168g-3
  - rtl_nic: add firmware rtl8106e-2
  - rtl_nic: add firmware rtl8411-2
  - rtl_nic: update firmware for RTL8168G
  - rtlwifi/rtl8188ee: Add firmware for new driver
  - tg3: Add EEE support firmware for 57766 cards
  - update Marvell SD8797-B0 firmware image
  - wl127x/wl128x: update firmwares
  - wl18xx: add default configuration binary
  - wl18xx: add version 2 of the wl18xx firmware
* Thu Feb 21 2013 Larry.Finger@lwfinger.net
- fix previous fix to build on factory/12.3
* Thu Feb 14 2013 Larry.Finger@lwfinger.net
- Updated to git snapshot 2013/1/14
  - carl9170: add firmware
  - qla2xxx: Update ql2400_fw.bin and ql2500_fw.bin to version 5.08.00
  - brcm: Add ucode support for bcm4313 iPA variant
  - linux-firmware: Add Marvell USB8797-B0 firmware image, Version 14.69.11.p179
  - s5p-mfc: Add s5p-mfc.fw for Exynos4 series
  - s5p-mfc: Add s5p-mfc-v6.fw for Exynos5 series
  - ar5523: Add firmware for new driver
  - Update patch and syscfg files for QCA9564
  - rtl_nic: Update firmware for RTL8168G to Version: 0.0.3
  - cxgb4: Update firmware to revision 1.6.2.0
  - bnx2x: Update fw to 7.8.2
  - r8712u: Revert to firmware from vendor driver v7_0.20100831
  - Update rampatch file for AR9462
  - netxen_nic: Update QLogic phanfw.bin to version 4.0.588
  - rtl8723e: Add firmware for new driver
  - ath6k: add firmware for AR6004 hw1.3
  - Marvell SD8787: update to v14.66.9.p96
  - Marvell SD8686: update to v9.70.20.p0
  - iwlwifi: update firmware for 6205 to version 18.168.6.1
* Fri Aug 24 2012 mmarek@suse.cz
- Package also license files (bnc#776576)
* Thu Jul 26 2012 jeffm@suse.com
- Updated to git snapshot 2012/7/19
  - brcm: add bcm4334 firmware for brcmfmac
  - r8712u: Update to latest firmware
  - rtl_nic: update firmware for RTL8168G
  - Add syscfg and patch files for AR3002 2.2.1
  - rtl_nic: add new firmware for RTL8168G, RTL8106E, RTL8411, RTL8168F
  - ar3k: add patch and sysconfig for Qualcomm Atheros AR9462
  - rtlwifi: rtl8192ce: rtl8192se: rtl8192de: Update to
    rtl_92ce_92se_92de_linux_mac80211_0004.0816.2011 driver
  - wl18xx: add firmware for WiLink8 WLAN chips
  - wl127x/wl128x: add new firmware series as version 5
  - rt2800pci:Firmware update v1
  - cxgb4: update firmware to revision 1.4.23.0
* Mon Jul  9 2012 jslaby@suse.de
- add carl9170-1.fw (bnc#763568)
* Tue Jun  5 2012 jeffm@suse.com
- Updated to git snapshot 2012/5/21
  - Many updates and additions
  - Replaced by git version:
  - iwlwifi-105-6.ucode
  - iwlwifi-135-6.ucode
  - iwlwifi-2000-6.ucode
  - iwlwifi-2030-6.ucode
  - bnx2/bnx2-mips-06-6.2.3.fw
  - bnx2/bnx2-mips-09-6.2.1b.fw
  - t4fw.bin (also updated to 1.4.16.0)
  - Removed:
  - brcm/bcm4329-fullmac-4.txt (was a development board)
  - mwl8335_duplex.fw (driver never included)
  - Renamed:
  - libertas/lbtf_usb.bin -> lbtf_usb.bin (as requested by driver)
* Tue May  8 2012 jslaby@suse.cz
- Add 4 iwlwifi firmware files. (bnc#760857)
  iwlwifi-105-6.ucode
  iwlwifi-135-6.ucode
  iwlwifi-2000-6.ucode
  iwlwifi-2030-6.ucode
* Fri Mar  2 2012 jlee@novell.com
- Add 2 new bnx2 firmware files. (bnc#746686)
  bnx2/bnx2-mips-06-6.2.3.fw
  bnx2/bnx2-mips-09-6.2.1b.fw
* Wed Dec 14 2011 coolo@suse.com
- as spdx.org has no concept of firmware, we decided to mark it as
  SUSE-Firmware
* Tue Oct 25 2011 coolo@suse.com
- update from git, ftp.kernel.org is stil down. Some smaller updates
* Thu Aug 25 2011 mls@suse.de
- fix supplements generation with rpm-4.9
* Fri Aug 12 2011 dmueller@suse.de
- add provides/obsoletes for ath3k-firmware
- Update to 20110731:
  * iwlwifi-6000g2a-5.ucode: Updated to v17.168.5.3
  * ath6kl - Atheros support for AR6003 WiFi-Bluetooth combo module
  * drxk - Micronas DRX-K demodulator driver
  * ene-ub6250 -- ENE UB6250 SD card reader driver
- update qlogic firmware to 5.06.00 (bnc#702696)
- add iwlwifi-4965-1.ucode (was additionally in iwl4965-ucode
  package before)
- Add latest firmware (1.3.10.0) for cxgb4 from Chelsio git (bnc#711432)
* Tue Aug  9 2011 mmarek@suse.cz
- Remove the PE520.cis symlink, it was only needed for SLE11-SP2.
* Thu Aug  4 2011 dmueller@suse.de
- add provides/obsoletes for
  iwl100-ucode, iwl1000-ucode, iwl6000-ucode, iwl6050-ucode,
  iwl6000g2-ucode
* Mon Jul 25 2011 mmarek@novell.com
- Add symlink for cis/PE520.cis (bnc#707960#c8)
* Thu Jul 14 2011 dmueller@suse.de
- update to 20110709:
  * provides more stable iwlwifi drivers
  * remove the need for symlinking bcm43xx-0.fw
* Tue Jul 12 2011 mmarek@novell.com
- Revert the workaround for bnc#673054, the files exist in the
  tarball now.
* Tue Jul 12 2011 mmarek@novell.com
- Fix firmware.sh for 3.0
* Thu Feb 24 2011 gregkh@suse.de
- create symlinks for Broadcom driver (bnc#673054)
* Sat Feb  5 2011 johannesobermayr@gmx.de
- Add scm service for automatical updates
* Thu Dec 16 2010 gregkh@suse.de
- update to 20101214 version for 2.6.37+ kernel
* Wed Nov 24 2010 coolo@novell.com
- update to 20101113 tarball for 2.6.36+ kernel
* Thu Jul  1 2010 gregkh@suse.de
- update to the 20100617 tarball, which has lots of updates that
  the 2.6.34 kernel needs (bnc#619225).
* Fri May 14 2010 mmarek@suse.cz
- Do not install files already installed by the kernel (bnc#598624).
* Fri May 14 2010 mmarek@suse.cz
- firmware-supplements.sh: Fallback to the last installed kernel.
* Wed May 12 2010 mmarek@suse.cz
- Run firmware-supplements.sh at build time. It's not a perfect
  solution, because kernel-default has a different set of modules
  among architectures, but better than a manually updated file.
* Fri Apr 23 2010 mmarek@suse.cz
- Update firmware-supplements.txt using module aliases from
  kernel-desktop-2.6.34-5.2.i586 (bnc#598624).
* Fri Apr 23 2010 mmarek@suse.cz
- Silence the firmware-supplements.sh script.
* Thu Mar  4 2010 coolo@novell.com
- hacking find_supplements macro
* Thu Mar  4 2010 coolo@novell.com
- update supplements.txt
* Thu Mar  4 2010 coolo@novell.com
- update to 20100227 snapshot (no changelog provided)
* Tue Dec 15 2009 gregkh@suse.de
- update to 20091215 snapshot
- added RealTek 8192E firmware
* Mon Oct 12 2009 mmarek@suse.cz
- provide/obsolete iwl1000-ucode.
* Mon Oct  5 2009 mmarek@suse.cz
- Add a script to semi-automatically generate modalias supplements.
* Mon Oct  5 2009 mmarek@suse.cz
- provide obsoleted packages.
* Thu Oct  1 2009 mmarek@suse.cz
- update to 20090821
  * includes newer iwlwifi firmware (bnc#537112)
- use fdupes
* Mon Aug  3 2009 gregkh@suse.de
- add obsoletes for ralink-firmware (bnc#503836)
* Thu Apr 23 2009 gregkh@suse.de
- initial package
